## 1.7.7.20241221 (2024-12-21)

Update to mypy 1.14 (#13272)

## 1.7.7.20241127 (2024-11-27)

Remove obsolete OptExcInfo from sys (#13117)

## 1.7.7.20240813 (2024-08-13)

Use Generator instead of Iterator for 3rd-party context managers (#12481)

## 1.7.7.20240601 (2024-06-01)

Bump pynput to 1.7.7 (#12069)

## 1.7.6.20240511 (2024-05-11)

Pin pynput more tightly (#11897)

Fixes  #11896

## 1.7.5.20240423 (2024-04-23)

Add precise values for enum members where possible (#11299)

Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>
Co-authored-by: Alex Waygood <alex.waygood@gmail.com>

## 1.7.5.20240311 (2024-03-11)

Use Python 3.11 for third-party stubtest in CI (#11562)

## 1.7.5.20240205 (2024-02-05)

A new shade of Black (#11362)

## 1.7.5.20240106 (2024-01-06)

Update typing_extensions imports in third-party stubs (#11245)

## 1.7.5.20231222 (2023-12-22)

Bump mypy (and a few other test dependencies) (#11196)

## 1.7.5.7 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 1.7.5.6 (2023-03-27)

Add default values for third-party stubs beginning with 'P' (#9957)

## 1.7.5.5 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 1.7.5.4 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` (#9702)

## 1.7.5.3 (2022-11-23)

Mark pynput as completed (#9235)

## 1.7.5 (2022-09-12)

[pynput] Fix annotations of Controller.Key(Code) (#8722)

Document stubtest entries

## 1.7.4 (2022-09-10)

Run third-party stubtest under xvfb-run (#8719)

## 1.7.3 (2022-06-26)

Third-party stubs: audit `Callable[<parameters>, None]` annotations (#8175)

## 1.7.2 (2022-06-19)

stubtest: use separate table in METADATA.toml (#8096)

## 1.7.1 (2022-04-01)

Third-party stubs: Improve several `__exit__` methods (#7575)

## 1.7.0 (2022-02-24)

Add stubs for `pynput` package (#7177)

Fixes #4328

